// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
/*
 * Copyright (C) 2012 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Jussi Pakkanen <jussi.pakkanen@canonical.com>
 */

/*
 * These are the precompiled header includes for UnityCore.
 * Only system header files can be listed here.
 */

#include <vector>
#include <list>
#include <algorithm>
#include <string>
#include <map>
#include <memory>
#include <unordered_map>
#include <functional>

#include <boost/utility.hpp>
#include <dee.h>
#include <glib.h>
#include <gio/gio.h>
#include <NuxCore/Property.h>
#include <sigc++/sigc++.h>
